Clojure only.

protojure.pedestal.ssl


keystore->clj

(keystore-> {:keys [keystore key-password]})

Turn a keystore, which may be either strings denoting file paths or actual KeyStore instances, into an SSLContext instance

Turn a keystore, which may be either strings denoting file paths or actual KeyStore
instances, into an SSLContext instance
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries