protojure.pedestal.core

A Pedestal chain provider compatible with simultaneously serving both GRPC-HTTP2 and GRPC-WEB protocols

A [Pedestal](http://pedestal.io/) [chain provider](http://pedestal.io/reference/chain-providers) compatible with simultaneously serving both [GRPC-HTTP2](https://github.com/grpc/grpc/blob/master/doc/PROTOCOL-HTTP2.md) and [GRPC-WEB](https://github.com/grpc/grpc/blob/master/doc/PROTOCOL-WEB.md) protocols
raw docstring

add-close-listenerclj

(add-close-listener conn f)
source

chain-executeclj

(chain-execute request interceptors)
source

conn-idclj

(conn-id conn)
source

create-connectorclj

(create-connector {:keys [host port] :or {host "127.0.0.1"} :as connector-map})

Creates a PedestalConnector backed by Undertow HTTP/2.

Build connector-map with io.pedestal.connector: (-> (conn/default-connector-map host port) (conn/with-interceptors interceptors) (conn/with-routes routes))

Additional keys:

  • ::thread-pool : optional custom thread pool
  • :container-options : SSL config {:ssl-port, :keystore, :key-password}
Creates a PedestalConnector backed by Undertow HTTP/2.

Build connector-map with io.pedestal.connector:
  (-> (conn/default-connector-map host port)
      (conn/with-interceptors interceptors)
      (conn/with-routes routes))

Additional keys:
- ::thread-pool      : optional custom thread pool
- :container-options : SSL config {:ssl-port, :keystore, :key-password}
sourceraw docstring

disconnect!clj

(disconnect! channel)
source

handle-disconnectclj

(handle-disconnect connections k)
source

subscribe-closeclj

(subscribe-close connections exchange)
source

unsubscribe-closeclj

(unsubscribe-close connections exchange)
source

write-datacljmultimethod

Writes the provided bytes to the undertow response channel

Writes the provided bytes to the undertow response channel
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries